@@ -1,8 +1,6 @@
 !=======================================================================
 !
-!  PROGRAM  PHASE/0 2014.01 (rev.375)
-!
-!  "First-principles Electronic Structure Calculation Program"
+!  PROGRAM  PHASE/0 2017.01 ($Rev: 570 $)
 !
 !  MODULE: m_FFT
 !
@@ -31,6 +29,9 @@
 !     Since 2006, this program set has been developed as a part of the
 !  national project "Revolutionary Simulation Software (RSS21)", which
 !  is supported by the next-generation IT program of MEXT of Japan.
+!   Since 2013, this program set has been further developed centering on PHASE System
+!  Consortium.
+!   The activity of development of this program set has been supervised by Takahisa Ohno.
 !
 !
   integer, private      :: istat = 0
@@ -404,7 +405,7 @@ contains
           if(ipri >= 2) write(nfout,*) 'nl,nm,nn,id,id2,id3=',nl,nm,nn,id,id2,id3
           call qfr3bf(nl,nm,nn,afft,id,id2,id3,isw,ifax_WF,trigs_WF,ftw,itask,ier1)
        else if(kimg == 2) then
-          isw = flag_asl_cfft(inverse_or_direct)
+          isw = -flag_asl_cfft(inverse_or_direct)
           call hfc3bf(nl,nm,nn,afft,id,id2,id3,isw,ifax_WF,trigs_WF,ftw,itask,ier1)
        end if
     else if(electron_or_positron == POSITRON) then
